@@ -129,11 +129,15 @@ class PreprocessError(Exception):
 class ProphetDetector(BaseDetector):
     """ProphetDetector."""
 
+    # TODO: [CLOUD-2823] Deprecate use of class variable to indicate integer type metrics
+    integer_type_metrics = ["row_count", "duplicate_count", "missing_count", "invalid_count"]
+
     def __init__(
         self,
         logs: Logs,
         params: Dict[str, Any],
         time_series_data: pd.DataFrame,
+        metric_name: str,
         has_exegonenous_regressor: bool = False,
     ) -> None:
         """Constructor for ProphetDetector
@@ -166,6 +170,7 @@ class ProphetDetector(BaseDetector):
         self._is_trained: bool = False
         self._has_exogenous_regressor = has_exegonenous_regressor
         self.time_series_data = time_series_data  # this gets potentially rewritten when runnin skip measurements
+        self.uncertainty_bounds_require_integer_rounding: bool = metric_name in self.integer_type_metrics
 
         # public attrs
         self.model: Prophet
@@ -319,6 +324,8 @@ class ProphetDetector(BaseDetector):
         self.time_series = self.time_series.resample(self.freq_detection_result.inferred_frequency).mean()
         self.time_series = self.time_series.reset_index()
         self.time_series["y"] = self.time_series["y"].interpolate(**self._preprocess_params["interpolation_kwargs"])
+        if self._has_exogenous_regressor:
+            self.time_series["external_regressor"] = self.time_series["external_regressor"].fillna(0)
 
     def setup_fit_predict(self):
         """Sets up Prophet model and fits it on the self.time_series_data."""
@@ -370,14 +377,26 @@ class ProphetDetector(BaseDetector):
         assert (
             self._is_trained
         ), "ProphetDetector has not been trained yet. Make sure you run `setup_and_train_ts_model` first"
+
+        # pick out n-last points to detect anomalies for
+        if self._n_points:
+            self.predictions = self.predictions.iloc[-self._n_points :]  # noqa: E203
+
         self.predictions["real_data"] = self.time_series["y"].reset_index(drop=True)
 
         self._logs.debug(f"Anomaly Detection: detecting anomalies for the last {self._n_points} points.")
-
         # round/trucate because floats are shit and cause precision errors
-        self.predictions["real_data"] = self.predictions["real_data"].round(10)
-        self.predictions["yhat_lower"] = self.predictions["yhat_lower"].round(10)
-        self.predictions["yhat_upper"] = self.predictions["yhat_upper"].round(10)
+        latest_measurement = self.predictions.iloc[-1]
+        no_integer_between_bounds = (
+            np.abs(np.ceil(latest_measurement["yhat_upper"]) - np.floor(latest_measurement["yhat_lower"])) < 2
+        )
+        if no_integer_between_bounds and self.uncertainty_bounds_require_integer_rounding:
+            self.predictions["yhat_lower"] = np.floor(self.predictions["yhat_lower"])
+            self.predictions["yhat_upper"] = np.ceil(self.predictions["yhat_upper"])
+        else:
+            self.predictions["real_data"] = self.predictions["real_data"].round(10)
+            self.predictions["yhat_lower"] = self.predictions["yhat_lower"].round(10)
+            self.predictions["yhat_upper"] = self.predictions["yhat_upper"].round(10)
 
         # flag data points that fall out of confidence bounds
         self.predictions["is_anomaly"] = 0
@@ -391,11 +410,7 @@ class ProphetDetector(BaseDetector):
         self.predictions.loc[np.isinf(self.predictions["anomaly_probability"]), "is_anomaly"] = 0
         self.predictions.loc[np.isinf(self.predictions["anomaly_probability"]), "anomaly_probability"] = 0.0
 
-        # pick out n-last points to return to backend
-        if self._n_points:
-            self.anomalies = self.predictions.iloc[-self._n_points :]  # noqa: E203
-        else:
-            self.anomalies = self.predictions
+        self.anomalies = self.predictions
 
     def generate_severity_zones(self):
         assert (
